@@ -206,12 +206,12 @@ class KernelConnectionDialog(QDialog):
         ssh_form.addRow(_('Password'), self.pw)
         
         # Ok and Cancel buttons
-        accept_btns = QDialogButtonBox(
+        self.accept_btns = QDialogButtonBox(
             QDialogButtonBox.Ok | QDialogButtonBox.Cancel,
             Qt.Horizontal, self)
 
-        accept_btns.accepted.connect(self.accept)
-        accept_btns.rejected.connect(self.reject)
+        self.accept_btns.accepted.connect(self.accept)
+        self.accept_btns.rejected.connect(self.reject)
 
         # Dialog layout
         layout = QVBoxLayout(self)
@@ -219,7 +219,7 @@ class KernelConnectionDialog(QDialog):
         layout.addLayout(cf_layout)
         layout.addWidget(self.rm_cb)
         layout.addLayout(ssh_form)
-        layout.addWidget(accept_btns)
+        layout.addWidget(self.accept_btns)
                 
         # remote kernel checkbox enables the ssh_connection_form
         def ssh_set_enabled(state):
@@ -242,8 +242,9 @@ class KernelConnectionDialog(QDialog):
         self.kf.setText(kf)
 
     @staticmethod
-    def get_connection_parameters(parent=None):
-        dialog = KernelConnectionDialog(parent)
+    def get_connection_parameters(parent=None, dialog=None):
+        if not dialog:
+            dialog = KernelConnectionDialog(parent)
         result = dialog.exec_()
         is_remote = bool(dialog.rm_cb.checkState())
         accepted = result == QDialog.Accepted
@@ -255,7 +256,11 @@ class KernelConnectionDialog(QDialog):
                 falsy_to_none(dialog.pw.text()), # ssh password
                 accepted)                        # ok
         else:
-            return (dialog.cf.text(), None, None, None, accepted)
+            path = dialog.cf.text()
+            _dir, filename = osp.dirname(path), osp.basename(path)
+            if _dir == '' and not filename.endswith('.json'):
+                path = osp.join(jupyter_runtime_dir(), 'kernel-'+path+'.json')
+            return (path, None, None, None, accepted)
 
 
 #------------------------------------------------------------------------------
@@ -612,6 +617,11 @@ class IPythonConsole(SpyderPluginWidget):
         if not self.testing:
             self.initialize_plugin()
 
+        # Create temp dir on testing to save kernel errors
+        if self.testing:
+            if not osp.isdir(programs.TEMPDIR):
+                os.mkdir(programs.TEMPDIR)
+
         layout = QVBoxLayout()
         self.tabwidget = Tabs(self, self.menu_actions)
         if hasattr(self.tabwidget, 'setDocumentMode')\
@@ -784,6 +794,7 @@ class IPythonConsole(SpyderPluginWidget):
                          lambda fname, lineno, word, processevents:
                              self.editor.load(fname, lineno, word,
                                               processevents=processevents))
+        self.editor.breakpoints_saved.connect(self.set_spyder_breakpoints)
         self.editor.run_in_current_ipyclient.connect(
                                          self.run_script_in_current_client)
         self.main.workingdirectory.set_current_console_wd.connect(
@@ -1205,6 +1216,11 @@ class IPythonConsole(SpyderPluginWidget):
         self.activateWindow()
         shellwidget._control.setFocus()
 
+    def set_spyder_breakpoints(self):
+        """Set Spyder breakpoints into all clients"""
+        for cl in self.clients:
+            cl.shellwidget.set_spyder_breakpoints()
+
     #------ Public API (for kernels) ------------------------------------------
     def ssh_tunnel(self, *args, **kwargs):
         if os.name == 'nt':
@@ -1326,11 +1342,8 @@ class IPythonConsole(SpyderPluginWidget):
         kernel_manager._kernel_spec = self.create_kernel_spec()
 
         # Save stderr in a file to read it later in case of errors
-        if not self.testing:
-            stderr = codecs.open(stderr_file, 'w', encoding='utf-8')
-            kernel_manager.start_kernel(stderr=stderr)
-        else:
-            kernel_manager.start_kernel()
+        stderr = codecs.open(stderr_file, 'w', encoding='utf-8')
+        kernel_manager.start_kernel(stderr=stderr)
 
         # Kernel client
         kernel_client = kernel_manager.client()
